@@ -63,8 +63,11 @@ my %signals = (
 );
 
 sub new {
-	my ($class, $req) = @_;
+	#my ($class, $req) = @_;
+	my $class = shift;
+	my %def = (null_string => "null");
 	# my $self = $class->SUPER::new();
+=for comment
 	 my $self ={
 		dman => $$req{data_manager},
 		treeview => $$req{treeview},
@@ -74,8 +77,12 @@ sub new {
 		on_row_select => $$req{on_row_select},
 		multi_select => $$req{multi_select},   
 	};
-	
-	 bless $self, $class;
+=cut
+	my %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
+       	my $self;
+	@$self{qw(dman)} = delete @arg{qw(data_manager)};	
+	@$self{keys %arg} = values (%arg);
+	bless $self, $class;
 
 	 $self->{log} = Log::Log4perl->get_logger("Gtk2::Ex::DbLinker::Datasheet");
 	 my @cols = $self->{dman}->get_field_names ;
@@ -221,7 +228,7 @@ sub _setup_treeview {
 			# $renderer->set( editable => TRUE );
 			$field->{ $treeview_type . "_column" } = Gtk2::TreeViewColumn->new_with_attributes($field->{name}, $renderer, 'active' => $field->{column});
 		} elsif ($field->{renderer} eq "combo") {
-			 
+			$renderer->set_fixed_size($field->{x_percent}*20, -1) if ($field->{x_percent}); 
 			my $model = $self->_setup_combo($field->{name});
 		        $renderer->set(  editable => TRUE, text_column     => 1,	has_entry   => FALSE,  model => $model );
 			 $renderer->{col_data} = $lastcol++ ;
@@ -884,25 +891,25 @@ This gets the Rose::DB::Object::Manager (we could have use plain sql command, or
 
 This object is used to instanciante a RdbDataManager, that will be used in the datasheet constructor.
 
-      	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $datasheet_rows, meta => Rdb::Mytable->meta });
+      	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $datasheet_rows, meta => Rdb::Mytable->meta );
 
 We create the RdbDataManager for the combo rows
      
        	my $combo_data = Rdb::Combotable::Manager->get_combotable( select => [qw/t1.id t1.name/], sort_by => 'name');
-	my $dman_combo_1 = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $combo_data, meta => Rdb::Combotable->meta});
+	my $dman_combo_1 = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $combo_data, meta => Rdb::Combotable->meta);
 
 
 	my $combo2_data =  Rdb::Combotable2::Manager->get_combotable2( sort_by => 'country');
-	my $dman_combo_2 = Gtk2::Ex::DbLinker::RdbDataManager->new({ 
+	my $dman_combo_2 = Gtk2::Ex::DbLinker::RdbDataManager->new( 
 					     		data =>$combo2_data,
 						        meta => Rdb::Combotable2->meta,
-							});
+							);
 
 We create the Datasheet object with the columns description
 
 	my $treeview = Gtk2::TreeView->new();
 
-	$self->{datasheet} = Gtk2::Ex::DbLinker::Datasheet->new({
+	$self->{datasheet} = Gtk2::Ex::DbLinker::Datasheet->new(
 		treeview => $treeview,
 		fields => [{name=>"field1", renderer=>"text"},
 			{name=>"field2"}, 
@@ -914,7 +921,7 @@ We create the Datasheet object with the columns description
 			{name => 'idle', renderer => 'toggle'},
 				],
 		data_manager => $dman,		
-	});
+	);
 
 To change a set of rows in the table when we navigate between records for example, we fetch the rows using a object derived from Rose::DB::Object::Manager and pass it to the Gt2::Ex::DbLinker::RdbDatamanager object using the query method:
 
@@ -957,7 +964,9 @@ You would then typically connect some buttons to methods such as inserting, dele
 
 =head2 constructor
 
-The C<new()> method expects a hash reference of key / value pairs.
+The C<new()> method expects a list of parameters name => value or a hash reference of parameters name (keys) / value pairs.
+
+The parameters are:
 
 =over
 
