@@ -50,13 +50,13 @@ my %setter = (
 );
 
 my %getter = (
-	 'GtkEntry' => sub {my $w = shift; return $w->get_text;},
-	'GtkToggleButton' => sub { return shift->get_active;},
+	 'GtkEntry' => sub {my ($self, $w )= @_; return $w->get_text;},
+	'GtkToggleButton' => sub { my ($self, $w) = @_; my $v = $w->get_active; return (defined $v ? $v : 0)},
 	'GtkComboBox' => , \&_get_combobox_firstvalue,
 	'GtkComboBoxEntry' =>  \&_get_combobox_firstvalue,
-	'GtkCheckButton' => sub { return shift->get_active;},
-	'GtkSpinButton' => sub { return shift->get_active;},
-	'GtkTextView' => sub{my $textview = shift; my $buffer = $textview->get_buffer; 	return $buffer->get_text($buffer->get_bounds, FALSE);},
+	'GtkCheckButton' => sub { my ($self, $w)=@_;  my $v = $w->get_active; return (defined $v && length($v) ? $v : 0)},
+	'GtkSpinButton' => sub { my ($self, $w) = @_; return $w->get_active;},
+	'GtkTextView' => sub{my ($self, $textview) = @_; my $buffer = $textview->get_buffer; 	return $buffer->get_text($buffer->get_bounds, FALSE);},
 
 );
 
@@ -67,8 +67,10 @@ my %getter = (
 # sub {my $c = shift; print "getter_cbe\n"; my $iter = $c->get_active_iter; return $c->get_model->get( $iter ); }
 #
 sub new {
-	my ($class, $req)=@_;
-
+	my $class = shift;
+	#my ($class, $req)=@_;
+	my %def = (null_string => "null", rec_spinner=>"RecordSpinner", status_label=>"lbl_RecordStatus", rec_count_label=>"lbl_RecordCount", locale=>"fr_CH", auto_apply=>1);
+=for comment
 	my $self ={
 		dman => $$req{data_manager},
 		cols => $$req{datawidgets},
@@ -86,7 +88,14 @@ sub new {
 		auto_apply =>  (defined $$req{auto_apply} ?  $$req{auto_apply}  : 1),
 	
 	};
+=cut
+        my %arg = (ref $_[0] eq "HASH" ? (%def, %{$_[0]}) : (%def, @_));
+
+	my $self;
+	@$self{qw(dman cols)} = delete @arg{qw(data_manager datawidgets)};
+	@$self{keys %arg} = values (%arg);
 	 bless $self, $class;
+	
 	 #$self->{cols} = [];
 	 $self->_init;
  	my @dates;
@@ -186,8 +195,10 @@ sub add_combo_values {
 
 #dman must contains all the rows 
 sub add_combo{
-	my ($self, $req)=@_;
-
+	#my ($self, $req)=@_;
+	my $self = shift;
+	my %h;
+	my $req =  (ref $_[0] eq "HASH")? $_[0] : (%h =( @_)) && \%h;
 	my $combo = {
 		dman => $$req{data_manager}, 
 		id => $$req{id},
@@ -324,7 +335,7 @@ sub add_combo{
 
 sub _display_data {
 	my ($self, $pos ) = @_;
-	#  $self->{log}->debug( "display_data for row at pos " . $pos );
+	 $self->{log}->debug( "display_data for row at pos " . $pos );
 
 	my $dman = $self->{dman};
 
@@ -343,6 +354,7 @@ sub _display_data {
 		
 		my $w = $self->{datawidgets}->{$id};
 		my $name = $self->{datawidgetsName}->{$id};
+	
 		my $x;
 		#my $row = $self->{data}[$pos];
 	
@@ -379,7 +391,7 @@ sub _display_data {
 
 			}
 		}
-
+		$self->{log}->debug($name . " widget undef ") unless($w);
 		$setter{$name}($self, $w, $x) if($name && $setter{$name});
 	}
 	#$self->{pos}= $pos;
@@ -498,7 +510,7 @@ sub apply{
 			$self->{log}->debug($self->{datawidgetsName}->{$id});
 			my $coderef = $getter{ $self->{datawidgetsName}->{$id} };
 			
-			my $v  = &$coderef( $w );
+			my $v  = &$coderef($self, $w );
 		
 			$self->{log}->debug("apply id: $id value: ".  ($v?$v:""));
 
@@ -728,7 +740,7 @@ sub _set_combo {
 	my ($self, $w, $x) = @_;
 	$self->{log}->debug("set_combo value " . ( defined $x ? $x : " undef") . " widget: ". ref $w );
 	my $m = $w->get_model;
-	my $iter = $m->get_iter_first;
+	my $iter = $m->get_iter_first if($m);
 	 
         if ( ref $w eq "Gtk2::ComboBoxEntry" ) {
              $w->get_child->set_text( "" );
@@ -754,13 +766,16 @@ sub _set_combo {
 
 sub _set_check {
 	my ($self, $w, $x) = @_;
-	$w->set_active( $x );
+	$w->set_active( (defined $x ? $x : 0)  );
 }
 
 sub _get_combobox_firstvalue  {
-	my ($c) = @_; 
+	my ($self, $c) = @_; 
 	#print "getter_cb\n"; 
 	my $iter = $c->get_active_iter; 
+	 unless($iter) {
+		$self->{log}->debug("iter undef row: " . $c->get_active);
+	}
 	return ($iter ? $c->get_model->get( $iter,0) : undef ); 
 }
 
@@ -841,7 +856,7 @@ sub get_widget_value {
 	$self->{log}->debug("no widget found") unless ($w);
 	if ($w && $self->{datawidgetsName}) {
 		my $coderef = $getter{ $self->{datawidgetsName}->{$wid} };
-		$x  = &$coderef( $w ); 
+		$x  = &$coderef($self, $w ); 
 	}
 	$self->{log}->debug("found: " . ($x ? $x : " undef"));
 	return ($x ? $x: "");
@@ -853,7 +868,9 @@ sub update{
 	my @col = $self->{dman}->get_field_names;
 	$self->{log}->debug("update cols are " . (@col ? join(" " , @col) : " cols undef "));
 	if ( $self->{dman}->row_count > 0) {
-		$self->_display_data(0); 
+		$self->{rec_spinner}->set_value(1) if ($self->{rec_spinner});
+		$self->_display_data(0);
+	        
 	} else {
 		$self->_display_data(-1)
 	}
@@ -940,11 +957,11 @@ This gets the Rose::DB::Object::Manager (we could have use plain sql command, or
 
 	my $data = Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value]);
 
-	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data=> $data, meta => Rdb::Mytable->meta });
+	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data=> $data, meta => Rdb::Mytable->meta );
 
 This create the form.
 
-		$self->{form_coll} = Gtk2::Ex::DbLinker::Form->new({
+		$self->{form_coll} = Gtk2::Ex::DbLinker::Form->new(
 			data_manager => $dman,
 			meta => Rdb::Mytable->meta,
 			builder => 	$builder,
@@ -957,7 +974,7 @@ This create the form.
 				field_id2 => ["%Y-%m-%d", "%d-%m-%Y"], },
 			time_zone => 'Europe/Zurich',
 			locale => 'fr_CH',
-	    });
+	    );
 
 
 C<rec_spinner>, C<status_label>, C<rec_count_label> are Gtk2 widget used to display the position of the current record. See one of the example 2 files in the examples folder for more details. 
@@ -1012,13 +1029,13 @@ An other way is to create a data manager for the transaction table
 
 With DBI
 
-	$dman = Gtk2::Ex::DbLinker::DbiDataManager->new({ dbh => $self->{dbh}, sql =>{select =>"no_seller, no_product", from => "transaction", where => ""}});
+	$dman = Gtk2::Ex::DbLinker::DbiDataManager->new( dbh => $self->{dbh}, sql =>{select =>"no_seller, no_product", from => "transaction", where => ""});
 
 With Rose::DB::Object
 
 	$data = Rdb::Transaction::Manager->get_transaction(query=> [no_seller => {eq => $current_seller }]);
 
-	$dman = Gtk2::Ex::DbLinker::RdbDataManager->new({data => $data, meta=> Rdb::Transaction->meta});
+	$dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => $data, meta=> Rdb::Transaction->meta);
 
 And keep a reference of this for latter
 
@@ -1090,7 +1107,7 @@ such as inserting, moving, deleting, etc.
 
 =head2 constructor
 
-The C<new();> method expects a hash reference of key / value pairs
+The C<new();> method expects a list or a hash reference of parameters name => value pairs
 
 =over
 
@@ -1105,7 +1122,7 @@ C<builder> a Gtk2::GladeXML builder
 
 =back
 
-The following keys are optional
+The following parameters are optional:
 
 =over
 
@@ -1120,7 +1137,7 @@ widget called RecordSpinner.
 
 =item *
 
-C<rec_count_label>  name (default to "lblRecordCount") or a reference to a label that indicate the position of the current row in the rowset
+C<rec_count_label>  name (default to "lbl_RecordCount") or a reference to a label that indicate the position of the current row in the rowset
 
 =item *  
 
@@ -1145,10 +1162,12 @@ C<auto_apply> defaults to 1, meaning that apply will be called if a changed has
 Populates a Gtk2::ComboBox or Gtk2::ComboBoxEntry widget with a static list of values. 
 The array whose reference is stored in $array_ref is a list of array that described the rows: [[return value1, displayed value1], [...], ...]
 
-=head2 C<add_combo( {	data_manager =E<gt> $dman, 	id =E<gt> 'noed',  fields =E<gt> ["id", "nom"], }); >
+=head2 C<add_combo( {data_manager =E<gt> $dman, 	id =E<gt> 'noed',  fields =E<gt> ["id", "nom"], ); >
 
 Once the constructor has been called, combo designed in the glade file received their rows with this method. 
-The parameter is a hash reference, and the key and value are
+The parameter is a list of parameters name => value, or a hash reference of the same.
+
+The paramaters are:
 
 =over
 
